Examples
========

To help get you started using ``hankel``, we've compiled a few extended examples.
Other simple examples can be found in the API documentation for each object, or by looking at some of the tests.

.. toctree::
   :maxdepth: 2

   demos/getting_started
   demos/testing_forward_and_inverse_transforms
   demos/choosing_resolution_parameters
   demos/laplacian_hankel_vs_fft
